@@ -2,7 +2,7 @@ from Exceptions import *
 from Modes import Modes
 
 class TextFileHandler:
-    def __init__(self,path:str,mode:str="r"):
+    def __init__(self,path:str,mode:str=Modes.READ):
         self.path = path
         if mode == Modes.WRITE or mode == Modes.READ or mode == Modes.APPEND:
             self.mode = mode
